# openPMD-beamphysics
Tools for analyzing and viewing particle data in the openPMD standard, extension beamphysics.

https://github.com/openPMD/openPMD-standard/blob/upcoming-2.0.0/EXT_BeamPhysics.md

Installing openpmd-beamphysics
==============================

Installing `openpmd-beamphysics` from the `conda-forge` channel can be achieved by adding `conda-forge` to your channels with:

```
conda config --add channels conda-forge
```

Once the `conda-forge` channel has been enabled, `openpmd-beamphysics` can be installed with:

```
conda install openpmd-beamphysics
```

It is possible to list all of the versions of `openpmd-beamphysics` available on your platform with:

```
conda search openpmd-beamphysics --channel conda-forge
